@@ -347,9 +347,6 @@ class GitPkgCommitsCheck(GentooRepoCheck, GitCommitsCheck):
                 pkg_map['A'].add(pkg)
                 pkg_map['D'].add(pkg.old_pkg())
 
-        # modified packages in current repo
-        modified = [pkg for pkg in pkg_map['M'] if pkg not in pkg_map['D']]
-
         # run removed package checks
         if pkg_map['D']:
             yield from self.removal_checks(list(pkg_map['D']))
@@ -357,7 +354,7 @@ class GitPkgCommitsCheck(GentooRepoCheck, GitCommitsCheck):
         if pkg_map['R']:
             yield from self.rename_checks(list(pkg_map['R']))
         # run modified package checks
-        if modified:
+        if modified := [pkg for pkg in pkg_map['M'] if pkg not in pkg_map['D']]:
             yield from self.modified_checks(modified)
 
         for git_pkg in pkgset:
@@ -415,7 +412,7 @@ class MissingSignOff(results.CommitResult, results.Error):
         return f'commit {self.commit}, missing sign-off{s}: {sign_offs}'
 
 
-class InvalidCommitTag(results.CommitResult, results.Warning):
+class InvalidCommitTag(results.CommitResult, results.Style):
     """Local commit has a tag that is incompliant.
 
     Commit tags have restrictions as to the allowed format and data
@@ -433,7 +430,7 @@ class InvalidCommitTag(results.CommitResult, results.Warning):
         return f'commit {self.commit}, tag "{self.tag}: {self.value}": {self.error}'
 
 
-class InvalidCommitMessage(results.CommitResult, results.Warning):
+class InvalidCommitMessage(results.CommitResult, results.Style):
     """Local commit has issues with its commit message."""
 
     def __init__(self, error, **kwargs):
@@ -445,7 +442,7 @@ class InvalidCommitMessage(results.CommitResult, results.Warning):
         return f'commit {self.commit}: {self.error}'
 
 
-class BadCommitSummary(results.CommitResult, results.Warning):
+class BadCommitSummary(results.CommitResult, results.Style):
     """Local package commit with poorly formatted or unmatching commit summary.
 
     Git commit messages for packages should be formatted in the standardized
@@ -565,18 +562,24 @@ class GitCommitMessageCheck(GentooRepoCheck, GitCommitsCheck):
 
         # categorize package changes
         pkg_changes = defaultdict(set)
-        for pkg in commit.pkgs:
-            pkg_changes[pkg.category].add(pkg.package)
+        for atom in chain.from_iterable(commit.pkgs.values()):
+            pkg_changes[atom.category].add(atom)
 
         # check git commit summary formatting
         if len(pkg_changes) == 1:
-            category, pkgs = pkg_changes.popitem()
-            if len(pkgs) == 1:
+            category, atoms = pkg_changes.popitem()
+            if len({x.package for x in atoms}) == 1:
                 # changes to a single cat/pn
-                pkg = commit.pkgs[0]
-                if not re.match(rf'^({re.escape(pkg.key)}|{re.escape(pkg.cpvstr)}): ', summary):
-                    error = f'summary missing {pkg.key!r} package prefix'
+                atom = next(iter(atoms))
+                if not re.match(rf'^{re.escape(atom.key)}: ', summary):
+                    error = f'summary missing {atom.key!r} package prefix'
                     yield BadCommitSummary(error, summary, commit=commit)
+                # check for version in summary for singular, non-revision bumps
+                if len(commit.pkgs['A']) == 1:
+                    atom = next(iter(commit.pkgs['A']))
+                    if not atom.revision and not re.match(rf'^.+\bv?{re.escape(atom.version)}\b.*$', summary):
+                        error = f'summary missing package version {atom.version!r}'
+                        yield BadCommitSummary(error, summary, commit=commit)
             else:
                 # mutiple pkg changes in the same category
                 if not re.match(rf'^{re.escape(category)}: ', summary):
